#!/bin/sh

## This script clones all the different repos

set_up_2px_repo() {
  repo_name="$1"
  folder="$2"
  echo "Setting up $repo_name..."
  if [ -e ~/"$folder""$repo_name" ]; then
    echo "${GREEN}$repo_name is already there, updating...${NC}"
    cd ~/"$folder""$repo_name" && git pull
  else
    echo "${ORANGE}Cloning new $repo_name...${NC}"
    cd ~/"$folder" && git clone ssh://flyingscorpio@2px.info.tm/~/repos/"$repo_name".git
  fi

  return 0
}

set_up_gitlab_repo() {
  repo_owner="$1"
  repo_name="$2"
  folder="$3"
  echo "Setting up $repo_owner/$repo_name..."
  if [ -e ~/"$folder""$repo_name" ]; then
    echo "${GREEN}$repo_name is already there, updating...${NC}"
    cd ~/"$folder""$repo_name" && git pull
  else
    echo "${ORANGE}Cloning new $repo_name...${NC}"
    cd ~/"$folder" && git clone https://gitlab.com/"$repo_owner"/"$repo_name".git
  fi

  return 0
}

# REPOS ON LIME2 {{{

echo "Setting up Lessons..."
if [ ! -e ~/Lessons ]; then
  mkdir ~/Lessons && echo "${ORANGE}Created ~/Lessons${NC}"
fi
set_up_2px_repo 'E2L' 'Lessons/'
set_up_2px_repo 'OpenClassrooms' 'Lessons/'
set_up_2px_repo 'Keepass'
set_up_2px_repo 'PersonnalScripts'
set_up_2px_repo 'RootMe'
set_up_2px_repo 'SetupCockpit'
set_up_2px_repo 'VimConf'
cd ~/VimConf && /bin/bash ~/VimConf/update.sh -o

# }}}

# REPOS ON GITLAB {{{

if [ ! -e ~/SRC ]; then
  mkdir ~/SRC && echo "${ORANGE}Created ~/SRC${NC}"
fi

set_up_gitlab_repo 'e2li' 'depydoc' 'SRC/'
set_up_gitlab_repo 'flyingscorpio' 'BlurMySearches' 'SRC/'
set_up_gitlab_repo 'flyingscorpio' 'JsonToPython' 'SRC/'
set_up_gitlab_repo 'flyingscorpio' 'MarioSokoban' 'SRC/'
set_up_gitlab_repo 'flyingscorpio' 'PythonLocalBlockchain' 'SRC/'
set_up_gitlab_repo 'flyingscorpio' 'Roboc-GUI' 'SRC/'
set_up_gitlab_repo 'flyingscorpio' 'Roboc-console' 'SRC/'
set_up_gitlab_repo 'flyingscorpio' 'ScheduleTimer' 'SRC/'
set_up_gitlab_repo 'flyingscorpio' 'SudokuSolver' 'SRC/'
set_up_gitlab_repo 'flyingscorpio' 'TicTacToe' 'SRC/'
set_up_gitlab_repo 'flyingscorpio' 'TorNoVPN' 'SRC/'
set_up_gitlab_repo 'flyingscorpio' 'WhitespaceInterpreter' 'SRC/'
set_up_gitlab_repo 'flyingscorpio' 'WikipediaAcronymScraper' 'SRC/'

echo "Setting up 2px..."
if [ -e ~/SRC/2px ]; then
  echo "${GREEN}2px is already there, updating...${NC}"
  cd ~/SRC/2px && git pull
else
  echo "${ORANGE}Cloning new 2px...${NC}"
  cd ~/SRC && git clone git@gitlab.com:flyingscorpio/2px.git
  cd ~/SRC/2px && python3 -m venv env
  echo "
# Set own environment variables for Django
DJANGO_USER='flyingscorpio'
export DJANGO_USER
DJANGO_PASSWORD='ribosome66'
export DJANGO_PASSWORD
DJANGO_SECRET_KEY='q+hci0d5y90q)k07f@1k3qzr&w=@89n(0z0ukp)_iu(g9iws0r'
export DJANGO_SECRET_KEY
systemctl start mysqld.service" >> ~/SRC/2px/env/bin/activate
fi

echo "Setting up LVEL-website..."
if [ -e ~/SRC/LVEL-website ]; then
  echo "${GREEN}LVEL-website is already there, updating...${NC}"
  cd ~/SRC/LVEL-website && git pull
else
  echo "${ORANGE}Cloning new LVEL-website...${NC}"
  cd ~/SRC && git clone git@gitlab.com:flyingscorpio/LVEL-website.git
  cd ~/SRC/LVEL-website && python3 -m venv env
  echo "
# Set own environment variables for Django
DJANGO_USER='flyingscorpio'
export DJANGO_USER
DJANGO_PASSWORD='ribosome66'
export DJANGO_PASSWORD
DJANGO_SECRET_KEY='t!d6q&g1*lm-p41m=pd!o&kga9jk)wom)sr7#4-=\$oo*\$)ymtc'
export DJANGO_SECRET_KEY
systemctl start mysqld.service" >> ~/SRC/LVEL-website/env/bin/activate
fi

# }}}
